@@ -454,8 +454,7 @@ connection && Sys.getenv("NOT_CRAN") == "true" && {
   test_identical(m, n)
 }
 connection && requireNamespace("otelsdk", quietly = TRUE) && Sys.getenv("NOT_CRAN") == "true" && {
-  record <- otelsdk::with_otel_record({
-    mirai:::otel_refresh_tracer("mirai")
+  record <- mirai:::with_otel_record({
     url <- local_url()
     purl <- nanonext::parse_url(url)
     test_true(daemons(url = url, dispatcher = FALSE))
@@ -466,7 +465,6 @@ connection && requireNamespace("otelsdk", quietly = TRUE) && Sys.getenv("NOT_CRA
     test_true(is_error_value(m2[]))
     test_false(daemons(0))
   })
-  mirai:::otel_refresh_tracer("mirai")
   traces <- record$traces
   test_equal(length(traces), 15L)
   test_true(startsWith(traces[[1L]]$name, "daemons set"))
